from setuptools import setup, find_packages

setup(
    name="any-agents",
    version="0.1.1",
    packages=find_packages(),
    install_requires=["any-agent"],
    description="Redirect package for any-agent - you probably meant to install 'any-agent' instead",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/mozilla-ai/any-agents",
    author="Nathan Brake",
    author_email="nathan@mozilla.ai",
)



import warnings
import sys

warnings.warn(
    "\nYou have installed 'any-agents' (with an 's'), but you probably meant to install 'any-agent'.\n"
    "The correct package 'any-agent' has been automatically installed as a dependency.\n"
    "Please use 'any-agent' in your imports to avoid confusion.",
    UserWarning,
    stacklevel=2
)